@@ -23,7 +23,7 @@
 **********************************************************************
     brgtconv.c: output converters for B-Right/V(TM) variants
 	v1.92	Newly written from ucodeconv.c 
-    $Id: brgtconv.c,v 1.29 2013/04/07 03:34:21 seiji Exp seiji $
+    $Id: brgtconv.c,v 1.30 2013/07/22 13:45:58 seiji Exp seiji $
 **/
 
 #include <stdio.h>
@@ -378,11 +378,11 @@ void BRGT_ozone_oconv(c2)
     skf_ucode	c2;
 {
     int	ch, converted = 0;
+#ifdef SKFDEBUG
     int	c1,c3;
 
     c1 = c2 & 0xff;
     c3 = (c2 >> 8) & 0xff;
-#ifdef SKFDEBUG
     if (is_vv_debug) fprintf(stderr," BRGT_ozone: %03x,%02x",c3,c1);
 #endif
 
@@ -441,7 +441,7 @@ void BRGT_compat_oconv (c2)
 	    if (brgt_hwid == 0) {  /* convert to half-width	   */
 		BRGT_TURNHALF();
 	    };
-	    x0201conv(c1-0x40,0);
+	    (void)x0201conv(c1-0x40,0);
 	} else if ((c4 == 0xfe) && (c1 < 0x10)) { /* variation selector */
 		;			/* just discard		    */
 	} else {
