@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     convert.h	input side converter common header
-    $Id: convert.h,v 1.107 2012/01/04 14:26:56 seiji Exp seiji $
+    $Id: convert.h,v 1.108 2013/07/22 13:45:12 seiji Exp seiji $
 */
 #ifndef CONVERT_H_DEFINED
 #define CONVERT_H_DEFINED
@@ -110,8 +110,10 @@ extern void g3table2up();
 #define DEC_HOOK_UTF16	0
 #define DEC_HOOK_UTF8	1
 #define DEC_HOOK_UTF7	2
+#define DEC_HOOK_UTF32	3
 
 #define is_cod_utf16(x)	(x == DEC_HOOK_UTF16)
+#define is_cod_utf32(x)	(x == DEC_HOOK_UTF32)
 #define is_cod_utf8(x)	(x == DEC_HOOK_UTF8)
 #define is_cod_utf7(x)	(x == DEC_HOOK_UTF7)
 
