@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
 ** error.c:	error message related routine in skf
-** $Id: error.c,v 1.134 2013/04/07 03:34:21 seiji Exp seiji $
+** $Id: error.c,v 1.135 2013/07/22 13:45:12 seiji Exp seiji $
 **	out_area_out:	error character warning generation
 **	bogus_out:	same as above
 **
@@ -131,7 +131,7 @@ skf_err_msg = skf_gettext("skf: not in right plain code set (%4x)");
 	    break;
 	case SKF_UNDEFCSET:
 skf_err_msg = skf_gettext("skf: undefined code set is specified\n");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    break;
 	case SKF_NOSURRG:
 	    skf_err_msg = 
@@ -230,7 +230,7 @@ skf_err_msg = skf_gettext("skf: This code(u:%4x) is undefined - ");
 	    break;
 	case SKF_UX0212:
 skf_err_msg = skf_gettext("skf: JIS X-0212 is disabled under ");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    skf_outcode_display(); fprintf(skfstderr,"\n");
 	    break;
 	case SKF_OUNDEF:
@@ -466,6 +466,8 @@ int mode;
 
 #ifdef SKFDEBUG
   if (is_v_debug || (mode > 0)) {
+#else
+  if (mode > 0) {
 #endif
     skf_err_msg = skf_gettext("OPTIONS: ");
     fprintf(skfstderr,skf_err_msg);
@@ -538,10 +540,9 @@ int mode;
     fprintf(skfstderr,"UID ");
 #endif
 #endif
-    fputc('\n',skfstderr);
-#ifdef SKFDEBUG
+    (void)fputc('\n',skfstderr);
   } else;
-#endif
+
     skf_err_msg = skf_gettext("FEATURES: ");
     fprintf(skfstderr,skf_err_msg);
 #ifdef KUNIMOTO
@@ -585,7 +586,7 @@ int mode;
     if (is_lineend_cr) fprintf(skfstderr,"LE_CR ");
     if (is_lineend_lf) fprintf(skfstderr,"LE_LF ");
 
-    fputc('\n',skfstderr);
+    (void)fputc('\n',skfstderr);
 
 #ifdef SKFDEBUG
     if (is_v_debug) {
@@ -619,7 +620,7 @@ int mod;
 void error_code_option(code)
 int	code;
 {
-    fputs(skf_err_header,skfstderr);	/* header		   */
+    (void)fputs(skf_err_header,skfstderr);/* header		   */
     switch (code) {
 	case SKF_MISCSETOPT:
     skf_err_msg = skf_gettext("missing character set option!\n");
@@ -696,7 +697,8 @@ void initialize_error()
 #endif
     skf_err_buf = (char *)calloc(256,sizeof(char));
     if (skf_err_buf == NULL) {
-	skferr(SKF_MALLOCERR,(long)0,(long)0); skf_exit(EXIT_FAILURE);
+	skferr(SKF_MALLOCERR,(long)0,(long)0);
+	skf_exit(EXIT_FAILURE);
     };
 #ifdef SWIG_EXT
     skf_swig_result = SKF_MALLOCERR;
@@ -767,11 +769,11 @@ long	a1,a2;
 	    skf_err_msg = skf_gettext(
 	    "unassigned error(%s)\n");
       };
-      fputs(skf_err_header,skfstderr);	/* header		   */
+      (void)fputs(skf_err_header,skfstderr);  /* header		   */
       fprintf(skfstderr,skf_err_msg,(code - SKF_TABLEERR_G0),
 	(tdefs == NULL) ? "(null)" : tdefs->desc);
     } else {
-      fputs(skf_err_header,skfstderr);	/* header		   */
+      (void)fputs(skf_err_header,skfstderr);	/* header	   */
       switch (code) {
 	case SKF_OBUFREERR:
 	    fprintf(skfstderr,"re-");		/*@FALLTHROUGH@*/
@@ -784,26 +786,26 @@ long	a1,a2;
 	case SKF_EUCPRESETERR:
 	    skf_err_msg = skf_gettext(
 		"EUC table loading error\n");
-	    fputs(skf_err_msg, skfstderr); break;
+	    (void)fputs(skf_err_msg, skfstderr); break;
 	case SKF_TBLALLOCERR:
 	    skf_err_msg = skf_gettext(
 		"failed to allocate table for conversion\n");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    break;
 	case SKF_DECOMPERR:
 	    skf_err_msg = 
 		skf_gettext("decompose internal sequencer failed\n");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    break;
 	case SKF_INTERNALERR:
 	    skf_err_msg = 
 		skf_gettext("decode internal sequencer failed\n");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    break;
 	case SKF_PUTFAILERR:
 	    skf_err_msg = 
 		skf_gettext("can't send output character\n");
-	    fputs(skf_err_msg, skfstderr);
+	    (void)fputs(skf_err_msg, skfstderr);
 	    break;
 	case SKF_DEBUGERR_1:
 	    skf_err_msg = 
@@ -834,7 +836,7 @@ int	mode;
 {
     int res;
 
-    fflush(stdout);
+    (void)fflush(stdout);
     if (mode == 1) {
 	res = snprintf(skf_err_buf,255,
 		skf_gettext("skf: can't open output file %s\n"), fnam);
@@ -864,11 +866,11 @@ int	mode;
 		skf_gettext("skf: can't open input file %s\n"), fnam);
     };
     if ((res >= 0) && (res <= 256)) {	/* glibc workaround	   */
-	fputs(skf_err_buf,skfstderr);
+	(void)fputs(skf_err_buf,skfstderr);
     } else {
 	fprintf(skfstderr,"skf: can't open file %s\n", fnam);
     };
-    fflush(skfstderr);
+    (void)fflush(skfstderr);
 #ifdef SWIG_EXT
     skf_swig_result = SKF_OPENERR;
 #endif
@@ -879,8 +881,8 @@ int	mode;
 void skf_readerr(geterrno)
 int	geterrno;
 {
-    fflush(stdout);
-    if (geterrno != EAGAIN) fputs(skf_err_header,skfstderr);
+    (void)fflush(stdout);
+    if (geterrno != EAGAIN) (void)fputs(skf_err_header,skfstderr);
 			/* header		   */
 #ifndef SWIG_EXT
     if (geterrno == EISDIR) {
@@ -894,7 +896,7 @@ int	geterrno;
 	fprintf(skfstderr,skf_err_msg,in_file_name);
     };
 #endif
-    fflush(skfstderr);
+    (void)fflush(skfstderr);
 #ifdef SWIG_EXT
     skf_swig_result = SKF_READERR;
 #endif
@@ -946,7 +948,7 @@ void	skf_incode_display()
 	fprintf(skfstderr,"%s",i_codeset[in_codeset].desc);
     } else {
 	skf_err_msg = skf_gettext("Unknown(auto detect)");
-	fputs(skf_err_msg,skfstderr);
+	(void)fputs(skf_err_msg,skfstderr);
     };
     if (detect_cr || detect_lf) {
 	fprintf(stderr," ");
@@ -970,9 +972,9 @@ void	skf_outcode_display()
 	    i_codeset[out_codeset].oconv_type);
     } else {
 	skf_err_msg = skf_gettext("Unknown(internal error)");
-	fputs(skf_err_msg,skfstderr);
+	(void)fputs(skf_err_msg,skfstderr);
     };
-    fflush(skfstderr);
+    (void)fflush(skfstderr);
 }
 /* --------------------------------------------------------------- */
 void test_support_charset()
@@ -987,7 +989,7 @@ void test_support_charset()
 	("Supported charset: cname descriptions (* indicate extenal table)\n");
     fprintf(skfstderr,skf_err_msg);
 
-    fflush(skfstderr); fflush(stdout);
+    (void)fflush(skfstderr); (void)fflush(stdout);
     for (i=0; iso_ubytedef_table[i].ientry != NULL; i++) { 
 	fprintf(skfstderr,"# %s:\n",iso_ubytedef_table[i].desc);
 	uentry = iso_ubytedef_table[i].ientry;
@@ -1039,7 +1041,7 @@ void test_support_codeset()
 	("Supported codeset: cname description \n");
     fprintf(skfstderr,skf_err_msg);
 
-    fflush(skfstderr); fflush(stdout);
+    (void)fflush(skfstderr); (void)fflush(stdout);
     for (i=0; !is_code_invalid(i_codeset[i].encode); i++) { 
 	skf_cname = i_codeset[i].cname;
 	if (skf_cname == NULL) skf_cname = " -   ";
@@ -1061,7 +1063,7 @@ void debug_analyze()
     if (is_v_debug) {
 	trademark_warn();
 	trans_txt = skf_gettext("output codeset: ");
-	fputs(trans_txt,skfstderr);
+	(void)fputs(trans_txt,skfstderr);
 	skf_outcode_display();
 	fprintf(skfstderr,"conv_cap:%08lx ",conv_cap);
 	if (hk_enbl) fprintf(skfstderr,"X-0201 kana ");
@@ -1122,7 +1124,7 @@ void debug_analyze()
 	};
 	fprintf(skfstderr,"\n");
 	trans_txt = skf_gettext("input code set: ");
-	fputs(trans_txt,skfstderr);
+	(void)fputs(trans_txt,skfstderr);
 	skf_incode_display();
 	if (preconv_opt || encode_cap) {
 	    fprintf(skfstderr," -");
