@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     esc_process.c	escape sequence handler
-    $Id: esc_process.c,v 1.6 2010/11/01 12:41:10 seiji Exp $
+    $Id: esc_process.c,v 1.7 2013/12/19 15:06:35 seiji Exp seiji $
 */
 
 #include <stdio.h>
@@ -739,6 +739,11 @@ int esc_process(f)	/* escape parsing process.		   */
 	if (is_vv_debug) fprintf(stderr," private3 seqs(%x)..",c1);
 #endif
 	return(0);
+/* --------------------------------------------------------------- */
+    } else if (c1 >= ASCII_END) {
+	oconv(sFLSH);
+	ox_ascii_conv(A_ESC);  /* output as it is		   */
+	return(c1);
 /* --------------------------------------------------------------- */
     } else if (!stripinvis) {	/* suppress terminal control code  */
 #ifdef SKFDEBUG
@@ -753,7 +758,14 @@ int esc_process(f)	/* escape parsing process.		   */
 	    oconv(sFLSH);
 	    ox_ascii_conv(A_ESC);  /* output as it is		   */
 	    ox_ascii_conv(c1);
-	    if ((c1 = vGETC(f)) != sEOF) ox_ascii_conv(c1);
+	} else if (c1 == A_ESC) { /* seems to be broken seqs.	   */
+	    ox_ascii_conv(A_ESC);  /* output as it is		   */
+	    if (!in_depth) {
+		in_depth = TRUE; c1 = esc_process(f);
+		in_depth = FALSE;
+	    } else {
+		ox_ascii_conv(c1); c1 = seq_sweep(f,TRUE);
+	    };
 	} else {            	/* skf doesn't know the sequence   */
 	    oconv(sFLSH);
 	    ox_ascii_conv(A_ESC);   /* output as it is		   */
@@ -779,8 +791,18 @@ int	out;		/* out: output character if TRUE	   */
 {
    	register int c1;
 
+#ifdef SKFDEBUG
+	if (is_vv_debug) fprintf(stderr," sswp");
+#endif
 	while ((c1 = vGETC(f)) != sEOF) {
-	    if (c1 >= '@') {	/* in ISO-2022 terminate ch. area  */
+#ifdef SKFDEBUG
+	    if (is_vv_debug) fprintf(stderr,"%c%02x",((out) ? '+':'-'),c1);
+#endif
+	    if (c1 >= ASCII_END) { /* this is not term seqs.	   */
+	        unGETC(c1,f);
+	    	break;
+	    } else
+	    	if (c1 >= '@') {/* in ISO-2022 terminate ch. area  */
 	    /* --- note: actual termination char is > 0x30, but	   */
 	    /* 0x30-0x3f is reserved for private purpose, and not  */
 	    /* likely to be contained in standard network message. */
@@ -795,12 +817,18 @@ int	out;		/* out: output character if TRUE	   */
 		    } else {	/* second time ;-( trash them.	   */
 		    	continue;
 		    };
-		} else oconv(c1);
+		} else if (out) { oconv(c1);
+		} else;
 		break;			/* stop sweeping	   */
 	    } else {
 	    	if (out) oconv(c1); /* pass through.	   */
 	    };
 	};
+#ifdef SKFDEBUG
+	if (is_vv_debug) {
+	    fprintf(stderr,"!"); fflush(stderr);
+	} else;
+#endif
 	return(c1);
 }
 
