@@ -23,7 +23,7 @@
 **********************************************************************
     genoconv.c:	input/output converters seed
 	v1.90	Newly written from unic*de.c parsing
-    $Id: genoconv.c,v 1.138 2012/03/17 08:22:12 seiji Exp seiji $
+    $Id: genoconv.c,v 1.140 2013/12/19 15:10:25 seiji Exp seiji $
 **/
 
 #include <stdio.h>
@@ -804,9 +804,11 @@ void @gen@_private_oconv (c2)	/* u+d800 to u+f8ff		   */
     skf_ucode    c2;
 {
     int		ch;
+#if (!defined(SKFKEISSW) && !defined(SKFBGSW)) || defined(SKFDEBUG)
     int		c1;
 
     c1 = (c2 & 0xff);
+#endif
     ch = (c2 >> 8) & 0xff;
 
 #ifdef SKFDEBUG
@@ -814,8 +816,8 @@ void @gen@_private_oconv (c2)	/* u+d800 to u+f8ff		   */
 	ch,c1);
 #endif
 
-#if !defined(SKFKEISSW)
-    if (o_encode) out_@gen@_encode(c2,c2);
+#if !defined(SKFKEISSW) && !defined(SKFBGSW)
+    if (o_encode) out_@gen@_encode(c2,c1);
 #endif
     if (c2 < 0xe000) {
     		/* some (x-0213, emoticon) has reverse maps */
@@ -1030,12 +1032,17 @@ skf_ucode convch;	/* table lookup result */
     int slen = 0;	/* controls and GR's			   */
 
 #if defined(SKFBGSW) || defined(SKFSJISSW)
-    skf_ucode c1,c3;
+    skf_ucode c3;
+#if defined(SKFSJISSW)
+    skf_ucode c1;
+#endif
 #if !defined(SKFBGSW)
     skf_ucode p3;
 #endif
 
+#if defined(SKFSJISSW)
     c1 = (convch >> 8) & 0xffU;
+#endif
     c3 = convch & 0xffU;
 #endif
 
@@ -1051,10 +1058,18 @@ skf_ucode convch;	/* table lookup result */
 		    ;
 		} else if ((ch == '<') &&
 			(is_intext_mail || is_intext_maillike)) {
-		    mime_clip_test(1,-12);
+		    (void)mime_clip_test(1,-12);
 		    /* FIXME */
-		} else mime_clip_test(1,0); 
+		} else (void)mime_clip_test(1,0); 
 				/* if ascii, result should be 1	   */
+#if defined(USE_TRUE_MIME_TAIL)
+		if ((table_mime_tail(ch) || is_white(ch)) 
+			&& o_encode_stat
+			&& !no_early_mime_out(nkf_compat)
+			&& is_o_encode_mime(o_encode)) {
+		    o_c_encode(sSUSP);
+		} else;
+#endif
 		return;
 	    } else if (is_big5fam(conv_cap)) {
 	    	if (is_gb18030(conv_cap) && (convch > 0x8000)) {
@@ -1282,7 +1297,16 @@ skf_ucode convch;	/* table lookup result */
 			/* will be handled again in plug_converts. */
 		;	/* but test with 0,0 anyway		   */
 	};
-	mime_clip_test(plen,slen);
+	(void)mime_clip_test(plen,slen);
+#if defined(USE_TRUE_MIME_TAIL)
+    	if ((table_mime_tail(ch) || is_white(ch)) 
+		&& o_encode_stat
+		&& !no_early_mime_out(nkf_compat)
+		&& is_o_encode_mime(o_encode)) {
+		/* mime may stop here				   */
+	    o_c_encode(sSUSP);
+	} else;
+#endif
     } else {	/* if c1 < 0, output as it is.			   */
     	;
     };
