@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     in_converter.c	input-side converter
-    $Id: in_converter.c,v 1.170 2013/04/07 03:34:21 seiji Exp seiji $
+    $Id: in_converter.c,v 1.171 2013/07/22 13:42:44 seiji Exp seiji $
 */
 
 #include <stdio.h>
@@ -275,7 +275,7 @@ skfFILE *f;			/* can process euc, euc+jis-mix	   */
 
 #ifdef SKFDEBUG
 	    if (is_vv_debug) {
-		fprintf(stderr,"(%d)",ch); fflush(stderr);
+		fprintf(stderr,"(%d)",ch); (void)fflush(stderr);
 	    };
 #endif
 		/* normal JIS(X-0208, X-0212) case.	   */
@@ -1260,7 +1260,12 @@ skfFILE *f;
 #endif
     	decode_set(0);
     } else;
-    return(uni_in(f,DEC_HOOK_UTF16));
+    if ((in_codeset == codeset_utf32be)
+    	|| (in_codeset == codeset_utf32benb)) {
+	return(uni_in(f,DEC_HOOK_UTF32));
+    } else {
+	return(uni_in(f,DEC_HOOK_UTF16));
+    };
 }
 
 /* --------------------------------------------------------------- */
@@ -1509,7 +1514,7 @@ int x;
 	} else;
     };
     return(0);
-};
+}
 
 /*@-usereleased@*/ /* Why this function needs this?	*/
 skf_ucode	viqr_parse(ch,ca,cv,ec)
@@ -2151,7 +2156,7 @@ skfFILE *f;			/* can process euc, euc+jis-mix	   */
 	    /* BROKEN JIS */
 #ifdef SKFDEBUG
 	    if (is_vv_debug) {
-		fprintf(stderr,"(%d)",ch); fflush(stderr);
+		fprintf(stderr,"(%d)",ch); (void)fflush(stderr);
 	    };
 #endif
 		/* normal JIS(X-0208, X-0212) case.	   */
@@ -2257,6 +2262,7 @@ skfFILE *f;			/* can process euc, euc+jis-mix	   */
 #endif
 		} else if (c1 == A_ESC) { /* escape treatment	   */
 		    if ((c1 = esc_process(f)) < 0) return(c1);
+		    c2 = 0; continue;
 		} else SKF_rotoconv(c1,mod); /* just pass other code. */
 		continue;
 	/* --- ASCII alphanumeric area --------------------------- */
