@@ -23,7 +23,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     in_decoder.c	input-side converter decode routines
-    $Id: in_decoder.c,v 1.68 2013/04/07 03:34:21 seiji Exp seiji $
+    $Id: in_decoder.c,v 1.69 2013/07/22 13:45:12 seiji Exp seiji $
 
     Punycode decode part is copyrighted by The Internet society.
 */
@@ -800,7 +800,9 @@ int	flg;
     int	pres = 0;		/* parse result			   */
     int i;			/* character decode limiter	   */
     int decode_hex = FALSE;
+#if 0
     unsigned long e_c_ss;
+#endif
     skf_ucode rcod;
     int postq_mark, isdigited;
 #ifndef NEW_SOFTWRAP_CODE
@@ -1054,13 +1056,13 @@ int	flg;
 		} else if (c1 == 'q') { sp_mime = SP_Q;
 		} else continue;  /* output postQueue as it is	   */
 #ifdef SKFDEBUG
-		if (is_vv_debug) fputc(c1,stderr); 
+		if (is_vv_debug) (void)fputc(c1,stderr); 
 #endif
 		if ((c1 = hook_q_getc(f,flg)) != '?') continue;	
 	      }; 	/* reached decoded part			   */
 	      decode_post_mark = decode_post_wptr; 
 #ifdef SKFDEBUG
-		if (is_vv_debug) fputc('H',stderr); 
+		if (is_vv_debug) (void)fputc('H',stderr); 
 #endif
 	      if (is_mimeb_strict) {
 #ifdef SKFDEBUG
@@ -1140,7 +1142,9 @@ int	flg;
 #endif
 	  };
 	} else if (in_mime && is_b_encode) {
+#if 0
 	  e_c_ss = encode_cap;		/* pre-save for recovery   */
+#endif
 #ifdef SKFDEBUG
 	  if (is_vv_debug) fprintf(stderr,"-B");
 #endif
@@ -1306,7 +1310,9 @@ int	flg;
 		for (i=decode_poke_buf;i<-5;i++) post_Qenque(A_SP);
 	  };
 #endif
+#if 0
 	  e_c_ss = encode_cap;
+#endif
 	  decode_poke_buf = -1;		/* throw anyway		   */
 	  if (c1 == '?') {		/* escape from mime	   */
 	    if ((c2 = hook_getc(f,flg)) != '=') {
@@ -1821,10 +1827,36 @@ int cod;
 		ch = ((c1 & Z4MSK) << 18) | ((c2 & Z43MSK) << 12)
 		    | ((c3 & Z1MSK) << 6) | (c4 & Z1MSK);
 	    } else ch = 0;
+	} else if (is_cod_utf32(cod)) {	/* utf-32 (a.k.a. UCS4)	   */
+#ifdef SKFDEBUG
+	  if (is_vv_debug) {
+	  	fprintf(stderr," U4:%d",in_codeset);
+	  } else;
+#endif
+	  GETC_add(c2,c1,f);
+	  GETC_add(c3,c1,f);
+	  GETC_add(c4,c1,f);
+	  if ((c1 == 0x00) && (c2 == 0x00) && (c3 == 0xfe)
+	  	&& (c4 == 0xff)) {
+	      if (!(endian_protect)) set_in_endian ;
+	      continue;
+	  } else if ((c4 == 0x00) && (c3 == 0x00) && (c2 == 0xfe)
+	  	&& (c1 == 0xff)) {
+	      if (!(endian_protect)) reset_in_endian ;
+	      continue;
+	  } else;
+	  if (in_endian) {
+	      ch = ((c1 & 0xffU) << 24) | ((c2 & 0xffU) << 16)
+	      		| ((c3 & 0xffU) << 8) | (c4 & 0xffU);
+	  } else {
+	      ch = ((c4 & 0xffU) << 24) | ((c3 & 0xffU) << 16)
+	      		| ((c2 & 0xffU) << 8) | (c1 & 0xffU);
+	  };
 	} else {		/* utf-16 (a.k.a. UCS2)		   */
 #ifdef SKFDEBUG
-	  if (is_vv_debug) fprintf(stderr," U2");
-	  if (is_vv_debug) fprintf(stderr,"%d ",in_codeset);
+	  if (is_vv_debug) {
+	  	fprintf(stderr," U2:%d",in_codeset);
+	  } else;
 #endif
 	    c2 = c1;
 	    GETC_add(c1,c2,f);
