@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
 ** oconv.c:	unic*de post-handler. called from in_converter.
-** $Id: oconv.c,v 1.140 2013/04/07 03:34:21 seiji Exp seiji $
+** $Id: oconv.c,v 1.142 2013/12/19 15:06:35 seiji Exp seiji $
 **
 **********************************************************************
 ** Notice for limitation of these converter programming.
@@ -122,7 +122,7 @@ static int	is_intag = FALSE; /* within HTML tags		   */
 static int		decompose_recursion_depth = 0;
 static skf_ucode	decompose_buf[32];
 static int		decompose_bufp;
-static void		decompose_code_dec P_((skf_ucode));
+static void		decompose_code_dec P_((unsigned short));
 
 #ifdef UNI_ENCOMPOSE
 static skf_ucode	encompose_buf[ENCOMPOSE_DEPTH];
@@ -183,9 +183,9 @@ static int default_enck_mask[ENCOMPOSE_MASK_LEN] = {
 
 /* --------------------------------------------------------------- */
 const char u_dakuten[96] = {
- 0,0,0,0,0,0,1,0,0,0,0,1,0,1,0,1,
- 0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,
- 0,1,0,0,1,0,1,0,1,0,0,0,0,0,0,3,
+ 0,0,0,0,0,0,1,0,0,0,0,4,0,4,0,4,
+ 0,4,0,4,0,1,0,1,0,1,0,4,0,1,0,1,
+ 0,1,0,0,4,0,1,0,4,0,0,0,0,0,0,3,
  0,0,3,0,0,3,0,0,3,0,0,3,0,0,0,0,
  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,
  1,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,
@@ -398,6 +398,10 @@ skf_ucode ch;
 #ifdef FOLD_SUPPORT
     int		charProp = 0;	/* character property buffer	   */
     char	kinsoku_stat;
+    int		trim = 0;
+#ifdef NKF_COMPATMODE
+    int		nkftrim = 0;
+#endif
 #endif
 
 #ifdef SKFDEBUG
@@ -428,7 +432,7 @@ skf_ucode ch;
 	    if ((ch >= 0xff61) && (ch <= 0xff9f) && 
 	        (is_nkf_no_hk ||
 		 (!hk_enbl && !(use_compat && is_ucs_ufam(conv_cap))))) {
-		x0201conv((ch - 0xff40),0xb0);
+		(void)x0201conv((ch - 0xff40),0xb0);
 		return;
 	    } else;
 	} else {
@@ -449,13 +453,60 @@ skf_ucode ch;
 			if (c1 == 0x06) sgbuf += 0x4e;
 			else if (sgbuf >= 0x30ef) sgbuf += 8;
 			else sgbuf += 1;
+			ch = sgbuf; sgbuf_buf = 0;
 		    } else if (((ch == U_KHDK) || (ch == U_LHDK)) &&
 			    (u_dakuten[c1] == 3)) {
-			sgbuf += 2; 
+			ch = sgbuf + 2; sgbuf_buf = 0;
+		    } else if ((ch == U_KHDK) && (u_dakuten[c1] == 4)) {
+			switch (sgbuf) {
+			    case 0x304b: ch = 0xd801; sgbuf_buf = 0; break;
+			    case 0x30ab: ch = 0xd808; sgbuf_buf = 0; break;
+			    case 0x304d: ch = 0xd802; sgbuf_buf = 0; break;
+			    case 0x30ad: ch = 0xd809; sgbuf_buf = 0; break;
+			    case 0x304f: ch = 0xd803; sgbuf_buf = 0; break;
+			    case 0x30af: ch = 0xd80a; sgbuf_buf = 0; break;
+			    case 0x3051: ch = 0xd804; sgbuf_buf = 0; break;
+			    case 0x30b1: ch = 0xd80b; sgbuf_buf = 0; break;
+			    case 0x3053: ch = 0xd805; sgbuf_buf = 0; break;
+			    case 0x30b3: ch = 0xd80c; sgbuf_buf = 0; break;
+			    case 0x30bb: ch = 0xd80d; sgbuf_buf = 0; break;
+			    case 0x30c4: ch = 0xd80e; sgbuf_buf = 0; break;
+			    case 0x30c8: ch = 0xd80f; sgbuf_buf = 0; break;
+			    default:
+				c1 = ch; ch = sgbuf;
+				sgbuf = c1;
+			};
 		    } else {
 			c1 = ch; ch = sgbuf;
 			sgbuf = c1;
 		    };
+		} else if ((sgbuf >= 0x00e6) && (sgbuf < 0x300) &&
+			   ((ch == 0x300) || (ch == 0x301))) {
+		    if ((sgbuf == 0x00e6) && (ch == 0x300)) {
+		    	ch = 0xd814; sgbuf_buf = 0;
+		    } else if (sgbuf == 0x0254) {
+		    	ch = 0xd818 + ((ch == 0x301) ? 1 : 0);
+			sgbuf_buf = 0;
+		    } else if (sgbuf == 0x028c) {
+		    	ch = 0xd81a + ((ch == 0x301) ? 1 : 0);
+			sgbuf_buf = 0;
+		    } else if (sgbuf == 0x0259) {
+		    	ch = 0xd81c + ((ch == 0x301) ? 1 : 0);
+			sgbuf_buf = 0;
+		    } else if (sgbuf == 0x025a) {
+		    	ch = 0xd81e + ((ch == 0x301) ? 1 : 0);
+			sgbuf_buf = 0;
+		    } else {
+			c1 = ch; ch = sgbuf;
+			sgbuf = c1;
+		    };
+		} else if ((sgbuf == 0x2e9) && (ch == 0x2e5)) {
+		    ch = 0xd820; sgbuf_buf = 0;
+		} else if ((sgbuf == 0x2e5) && (ch == 0x2e9)) {
+		    ch = 0xd821; sgbuf_buf = 0;
+		} else if ((sgbuf == 0x31f7) && 
+			   ((ch == U_KHDK) || (ch == U_LHDK))) {
+		    ch = 0xd807; sgbuf_buf = 0;
 		} else if ((sgbuf >= 0xff61) && (sgbuf <= 0xff9f) &&
 		    (is_nkf_no_hk ||
 		     (!hk_enbl && !(use_compat && is_ucs_ufam(conv_cap))))) {
@@ -531,7 +582,8 @@ skf_ucode ch;
 	    ch = 0x2d;
 	} else if (is_kanaconv_x0201 && 
 		(((ch >= 0x3041) && (ch <= 0x309c)) ||
-		 ((ch >= 0x30a1) && (ch <= 0x30fc)))) {
+		 ((ch >= 0x30a1) && (ch <= 0x30fc)) ||
+		 ((ch >= 0xd801) && (ch <= 0xd80f)))) {
 	    cnvpk = x0201rconv(ch);
 	    if (cnvpk != 0) {
 		c2 = ((cnvpk & 0xff00U) >> 8);
@@ -912,8 +964,17 @@ skf_ucode ch;
     } else if (ch < 0x10000) {	/* compatibility plane		  */
 #ifdef	FOLD_SUPPORT
 	if (fold_fclap > 0) {	/* if folding is enabled	  */
-	  if (fold_count > (fold_clap - 2)) {
-	    if (fold_count > fold_fclap) {
+#if 1
+	  if (is_nkf_convert_hook) { nkftrim = 1;
+	  } else;
+#endif
+	  trim = ((ch >= 0xff60) && (ch < 0xffe0)) ? 1 : 0;
+#ifdef NKF_COMPATMODE
+	  if (fold_count > (fold_clap - 2 + trim + nkftrim)) {
+#else
+	  if (fold_count > (fold_clap - 2 + trim)) {
+#endif
+	    if (fold_count > (fold_fclap + trim)) {
 		SKFCRLF(); fold_count = 0;
 	    } else if ((ch == 0xff08) || (ch == 0xff3b)
 		    || (ch == 0xff5b) || (ch == 0xff62)
@@ -941,7 +1002,7 @@ skf_ucode ch;
 	} else;
 #endif
 	o_compat_conv(ch);
-	fold_count += 2;
+	fold_count += (2 - trim);
     } else if ((ch >= 0x0e0000) && (ch <= 0x0e007f)) {
 			    /* input language tag		  */
 	if (ch == 0x0e0001) { 
@@ -1316,7 +1377,10 @@ skf_ucode c3;
 	SKFputc((int)(((d1 - 1) >> 1) + ((d1 <= 0x5e) ? 0x71 : 0xb1))); 
 	SKFputc((int) (d2 + ((d1 & 1) ? ((d2 < 0x60) ? 0x1f : 0x20) : 0x7e)));
     } else if (c3 < 0x7c7f) {/* ms_compat && nec_selected_ibm_gaiji */
-	if (c3 < 0x7c6f) {	/* Kanji area			   */
+    	if (is_nocp932) {	/* force MS mode		   */
+	    d3 = ((d1 - 1) >> 1) + ((d1 <= 0x5e) ? 0x71 : 0xb1); 
+	    d4 = (d2 + ((d1 & 1) ? ((d2 < 0x60) ? 0x1f : 0x20) : 0x7e));
+	} else if (c3 < 0x7c6f) {	/* Kanji area		   */
 	    d4 = d2 + ((d1 - 0x79) * 94) + 0x1c - 0x21;
 	    d3 = 0xfa;
 	    if (d4 >= 376) {
@@ -1860,6 +1924,9 @@ void SKFCRLF()
 	if (is_lineend_crlf || is_lineend_cr) ox_ascii_conv(A_CR);
 	if (is_lineend_crlf || is_lineend_lf) ox_ascii_conv(A_LF);
     };
+#ifdef FOLD_SUPPORT
+    fold_count = 0;
+#endif
 }
 
 /* --------------------------------------------------------------- */
