@@ -23,7 +23,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     out_encoder.c	output-side converter encode routines
-    $Id: out_encoder.c,v 1.21 2012/03/17 08:22:12 seiji Exp seiji $
+    $Id: out_encoder.c,v 1.22 2013/12/19 15:06:35 seiji Exp seiji $
 
     Punycode encode part is copyrighted by The Internet society.
 */
@@ -1141,12 +1141,15 @@ int	ch;
 	if (is_true_lineend(ch)) {
 	    SKFrCRLF();
 	};
+#if !defined(USE_TRUE_MIME_TAIL)
     } else if ((table_mime_tail(ch) || is_white(ch)) 
 		&& !no_early_mime_out(nkf_compat)
+		&& (!is_kanji_shift && !is_ucs_utf16(conv_cap))
 		&& is_o_encode_mime(o_encode)) {
 		/* Note: sFLSH and sEOF is also handled here	   */
 	o_encode_pend = 1;
 	enc_pre_enque(ch);
+#endif
     } else if ((o_encode_pend > 0)
 		&& !no_early_mime_out(nkf_compat)
 		&& is_o_encode_mime(o_encode)) {
@@ -1228,7 +1231,7 @@ void encoder_tail()
 	    o_encode_lc = 0;
 	    o_encode_lm = 0;
 #ifndef SWIG_EXT
-	    SKFrCRLF(o_encode);
+	    SKFrCRLF();
 #endif
 	} else;		/* should be none. no other coding exist   */
 	o_encode_stat = 0;	/* cleaned. now clear states.	   */
