@@ -23,7 +23,7 @@
 **********************************************************************
 ** plug_convert.c:	various converter routines for skf
 **		to treat something dirty ;-)
-** $Id: plug_convert.c,v 1.113 2012/03/17 08:22:12 seiji Exp seiji $
+** $Id: plug_convert.c,v 1.114 2013/07/22 13:42:44 seiji Exp seiji $
 **	x0201conv:	x0201 kana converter
 **	new2oldJis:	x0208(1983,1990) to C6226(1978)
 **	lig_x0213_out:	X0213/ISCII ligature out 
@@ -104,8 +104,8 @@ static const unsigned char kana_lwt[64] = {
 };
 
 const char dakuten[64] = { /* determine kana can have dakuten	  */
- 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,1,1,1,1,1,1,1,1,
- 1,1,1,1,1,0,0,0,0,0,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
+ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,4,4,4,4,4,1,1,1,4,1,
+ 1,1,4,1,4,0,0,0,0,0,3,3,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
 };
 
 int x0201conv(c,nxt)
@@ -128,12 +128,25 @@ int x0201conv(c,nxt)
 	if (dakuten[c3] > 0) {
 	    if (unxt == 0x5e) {	/* daku on			   */
 		if (c1 == 0x46)	c1 = 0x94; /* u -> vu		   */
-		else if (c1 == 0xa6) c1 = 0xf4; /* u -> vu	   */
+		else if (c1 == 0xa6)	c1 = 0xf4; /* u -> vu	   */
 		else c1 += 1; 	/* others.			   */
 		nxt = 0;
 	    } else if ((dakuten[c3] == 3) && (unxt == 0x5f)) {
 		c1 += 2;       /* han-dakuon              */ 
 		nxt = 0;
+	    } else if ((dakuten[c3] == 4) && (unxt == 0x5f)) {
+	    		/* X-0213 kana-handakuon hook		   */
+	    	switch (c3) {
+		    case 22: c1 = 0xd808 - 0x3000; nxt = 0; break;
+		    case 23: c1 = 0xd809 - 0x3000; nxt = 0; break;
+		    case 24: c1 = 0xd80a - 0x3000; nxt = 0; break;
+		    case 25: c1 = 0xd80b - 0x3000; nxt = 0; break;
+		    case 26: c1 = 0xd80c - 0x3000; nxt = 0; break;
+		    case 30: c1 = 0xd80d - 0x3000; nxt = 0; break;
+		    case 34: c1 = 0xd80e - 0x3000; nxt = 0; break;
+		    case 36: c1 = 0xd80f - 0x3000; nxt = 0; break;
+		    default: break;
+		};
 	    }; };
 
 	post_oconv(0x3000+c1);
@@ -163,12 +176,21 @@ static const unsigned short kana_revcnv[92] = {
   0x729e,0x749e,0x7c9e,0x65, 0x70
 };
 
+static unsigned short uni_lig_x0213_24[] = {
+    0x0000,0x304b,0x304d,0x304f, 0x3051,0x3053,0x0000,0x31f7,
+    0x30ab,0x30ad,0x30af,0x30b1, 0x30b3,0x30bb,0x30c4,0x30c8,
+    0x0000,0x0000,0x0000,0x0000, 0x00e6,0x0000,0x0000,0x0000,
+    0x0254,0x0254,0x028c,0x028c, 0x0259,0x0259,0x025a,0x025a
+};
+
 unsigned short x0201rconv(ch)
 skf_ucode ch;
 {
+    int c1,c2;
+
 #ifdef SKFDEBUG
     if (is_vv_debug)
-		fprintf(stderr," x0201rconv: %x",ch);
+		fprintf(stderr," x0201rconv:%x",ch);
 #endif
     if ((ch >= 0x3041) && (ch <= 0x3096)) {
     	return(kana_revcnv[ch - 0x3041]);
@@ -186,6 +208,19 @@ skf_ucode ch;
     	return(0x62);
     } else if (ch == 0x300d) {
     	return(0x63);
+    } else if ((ch >= 0xd801) && (ch <= 0xd80f)) {
+        c1 = uni_lig_x0213_24[ch - 0xd800];
+	if (c1 == 0) {
+	    return(0);
+	} else if (c1 < 0x30a0) {
+	    c2 = (kana_revcnv[c1 - 0x3041]) & 0xff;
+	    return((unsigned short)((c2 << 8) + 0x9f));
+	} else if (c1 < 0x3100) {
+	    c2 = (kana_revcnv[c1 - 0x30a1]) & 0xff;
+	    return((unsigned short)((c2 << 8) + 0x9f));
+	} else {
+	    return(0);
+	};
     } else {
     	return(0);
     };
@@ -196,12 +231,6 @@ skf_ucode ch;
 /* --------------------------------------------------------------- */
 /* lig_x0213_out: input - 0xd800 - 0xdfff			   */
 /* --------------------------------------------------------------- */
-static unsigned short uni_lig_x0213_24[] = {
-    0x0000,0x304b,0x304d,0x304f, 0x3051,0x3053,0x0000,0x31f7,
-    0x30ab,0x30ad,0x30af,0x30b1, 0x30b3,0x30bb,0x30c4,0x30c8,
-    0x0000,0x0000,0x0000,0x0000, 0x00e6,0x0000,0x0000,0x0000,
-    0x0254,0x0254,0x028c,0x028c, 0x0259,0x0259,0x025a,0x025a
-};
 
 static unsigned short uni_lig_emo_f9[16] = {
     0x23,0x30,0x31,0x32, 0x33,0x34,0x35,0x36,
@@ -233,7 +262,32 @@ skf_ucode ch;
 	if (c1 < 0x12) {    /* katakana/hiragana with han-dakuon   */
 	    c2 = uni_lig_x0213_24[c1];	/* 0x24xx, 0x25xx	   */
 	    if (c2 != 0) {
-		post_oconv(c2); post_oconv(0x309a);
+		post_oconv(c2);
+#if 1
+#ifdef NKF_COMPATMODE
+		if (!is_ms_213c(conv_cap) && !is_euc_213c(conv_cap)
+		    	 && !is_jis_213c(conv_cap) 
+#ifdef NKF_COMPATMODE
+			 && !is_nkf_compat
+#endif
+		     && (in_codeset != codeset_x0213)
+		     && (in_codeset != codeset_x213a)
+		     && (in_codeset != codeset_x0213_s)
+		     && (in_codeset != codeset_euc_213)
+		     && (in_codeset != codeset_euc_213a)
+		     && (in_codeset != codeset_sj_0213)
+		     && (in_codeset != codeset_sj_213a)
+			) {
+		    post_oconv(0x309c);
+		} else {
+		    post_oconv(0x309a);
+		};
+#else
+		post_oconv(0x309a);
+#endif
+#else
+		post_oconv(0x309a);
+#endif
 	    } else {
 		out_undefined(ch,SKF_IOUTUNI);
 	    };
@@ -399,6 +453,8 @@ static const char *uni_cjk_33_base[224] = {
     "p.m.", "ppm", "PR", "sr", "Sv", "Wb", "v/m", "a/m"
 };
 
+static const char *lit_gal = "gal";
+
 void CJK_sq_conv(c1)
 skf_ucode c1;
 {
@@ -415,7 +471,7 @@ skf_ucode c1;
     } else if ((c2 >= 0xe0) && (c2 <= 0xfe)) {
 	CJK_display_day(c2);
     } else if (c2 == 0xff) {
-	sym = (const char *)"gal";
+	sym = lit_gal;
     } else {
 	sym = uni_cjk_33_base[c2];
 	if (sym == NULL) {
@@ -541,7 +597,7 @@ skf_ucode c2;
 #ifdef UNICODE_1
 	post_oconv(0x2500 + uni_k_iroha[c1-0xd0]); /* Unic*de 1.0 */
 #else
-	x0201conv((c1-0x9f),0);
+	(void)x0201conv((c1-0x9f),0);
 #endif
 	post_oconv(0x29);
     } else if ((c1 >= 0xfc) && (c1 <= 0xfe)) { /* Enclosed kana */
