@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
     preconvert.c	code detector and converter
-    $Id: preconvert.c,v 1.115 2012/03/17 08:22:12 seiji Exp seiji $
+    $Id: preconvert.c,v 1.117 2013/12/19 15:11:08 seiji Exp seiji $
 */
 
 #include <stdio.h>
@@ -175,6 +175,11 @@ static int		rescase = 0;
 #endif
 
 static int	preconvert_counts = 0;
+#ifndef SWIG_EXT
+static char	*dcode_name = "DEFAULT_CODE";
+static char	*utf16be_name = "(UTF-16BE)";
+static char	*utf16le_name = "(UTF-16LE)";
+#endif
 
 /* --------------------------------------------------------------- */
 /* table of tables						   */
@@ -811,7 +816,7 @@ int preConvert (f)
 	    b5fault--; gbfault--; krfault--; hzfault--;
 	    /* --- Note: utf7 has no reason to salvage ----------- */
 	};
-	single_possible(jisfault,sjisfault,eucfault,utf8fault,
+	(void)single_possible(jisfault,sjisfault,eucfault,utf8fault,
 		utf7fault,ucs2fault,keisfault,latinfault,b5fault,
 		gbfault,krfault,hzfault);
 
@@ -1274,27 +1279,24 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 		  in_codeset = codeset_utf16le;
 		  has_bom = TRUE;
 		  if (!(endian_protect)) set_in_ltl_endian ;
-		  enque(rc1); break;
+		  enque(rc1); continue;
 	      } else if (Qempty && (c1 == 0xff) && (c2 == 0xfe)
 			  && is_lang_unicode) {
 		  set_rescase(131);
 		  in_codeset = codeset_utf16be;
 		  has_bom = TRUE;
 		  if (!(endian_protect)) set_in_big_endian ;
-		  enque(rc1); break;
+		  enque(rc1); continue;
 	      } else if (!Qempty && is_lang_unicode && 
 			  (((c1 == 0xff) && (c2 == 0xfe)) 
 			      || ((c1 == 0xfe) && (c2 == 0xff)))) {
 			      /* c1 must be fragment of code.	   */
-		  if (c2 == 0xfe) {
-		  	set_in_big_endian ;
-			in_codeset = codeset_utf16be;
-		  } else {
-		  	set_in_ltl_endian ;
-			in_codeset = codeset_utf16le;
-		  };
+		  if (c2 == 0xfe) set_in_big_endian ;
+		  else set_in_ltl_endian ;
+		  if (c1 == 0xff) in_codeset = codeset_utf16be;
+		  else in_codeset = codeset_utf16le;
 		  set_rescase(132); 
-		  enque(rc1); break;
+		  enque(rc1); continue;
 	      } else {		/* just not BOM			   */
 		  latinlikely += 2;	/* much likely		   */
 		  break;
@@ -2049,7 +2051,19 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 	} else {
 	  set_le_parse(le_n_cr_detect,le_n_lf_detect,le_n_crf_detect);
 	};
-	if (!detect_lf && !detect_cr) set_dummy_detect;
+	if (!detect_lf && !detect_cr) {
+	    set_dummy_detect;
+/* --- lineend default process --- */
+        /* no lineend detected. use default one */
+#ifdef DEFAULT_EOL_LF
+	    set_detect_lf;
+#else
+#ifdef DEFAULT_EOL_CRLF
+	    set_detect_lf;
+#endif
+	    set_detect_cr;
+#endif
+	} else;
 #ifdef SKFDEBUG
     } else {
 	if (is_v_debug && detect_cr) fprintf(stderr,"CR ");
@@ -2057,6 +2071,17 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 #endif
     };
 
+/* --- nkf codeset canonical name bug compatibility ------------ */
+    if (is_nkf_compat) {
+    	if (in_codeset == codeset_x0213) {
+	    in_codeset = codeset_x213a;
+	} else if (in_codeset == codeset_euc_213) {
+	    in_codeset = codeset_euc_213a;
+	} else if (in_codeset == codeset_sj_0213) {
+	    in_codeset = codeset_sj_213a;
+	} else ;
+    } else;
+
 /* --- clear detected endian before reading in_param ----------- */
     if (endian_protect) clear_in_endian;
 
@@ -2084,7 +2109,7 @@ sensed if it fits in ISO-2022 codeset-call sequence.
 #ifdef SKFDEBUG
     if ((is_v_debug) && (in_codeset >= 0) && !input_inquiry) {
 	debug_analyze();
-	fflush(stderr);
+	(void)fflush(stderr);
     };
 #endif
     if (input_inquiry && test_primary_codeset()) {
@@ -2161,7 +2186,7 @@ int	has_bom;
 	} else {
 	    codename = i_codeset[in_codeset].desc;
 	};
-    } else codename = "DEFAULT_CODE";
+    } else codename = dcode_name;
 
     if (out == 1) {
     	fprintf(stderr,"%s",codename);
@@ -2176,8 +2201,8 @@ int	has_bom;
 	};	
     };
     if (is_det_ucod) {
-	if (in_endian) codename = "(UTF-16BE) ";
-	else codename = "(UTF-16LE) ";
+	if (in_endian) codename = utf16be_name;
+	else codename = utf16le_name;
 	if (out == 1) {
 	    fprintf(stderr,"%s",codename);
 	} else {
