@@ -1,5 +1,5 @@
-#ident "$Id: skf.c,v 1.257 2013/04/07 03:34:21 seiji Exp seiji $"
-const char *rev = "SKF version 1.99.4 2013-04-17\n";
+#ident "$Id: skf.c,v 1.259 2013/12/19 15:06:35 seiji Exp seiji $"
+const char *rev = "SKF version 1.99.8 2014-01-18\n";
 /* *******************************************************************
 ** Copyright (c) 1993-2012 Seiji Kaneko. All rights reserved.
 ** Everyone is permitted to use this program in source and binary
@@ -189,8 +189,8 @@ skf_ucode	ucode_undef = 0;	/* substitute character	 */
 int		mime_fold_llimit = MIME_ENCODE_LLIMIT;
 				/* MIME line clip length	 */
 
-char            k_in = 0,	/* DEFAULT is unused in 1.92	 */
-		k_out = 0;
+char            k_in = (char)0,	/* DEFAULT is unused in 1.92	 */
+		k_out = (char)0;
 
 /* Global states */
 char		ucs_tagstr[6] = {   /* unic*de tag string buffer  */
@@ -211,7 +211,8 @@ static int	out_code = DEFAULT_O;	/* internal parse pass	  */
 char		*in_file_name;	/* input file name save area 	  */
 char		*out_file_name;	/* output file name save area 	  */
 char		*inb_file_name;	/* input file name save area 	  */
-char		*outb_file_name; /* output file name save area 	  */
+char		*outb_file_name = NULL; 
+				/* output file name save area 	  */
 char		*outs_file_name; /* suffix added to outfile name  */
 		/* used only with --in-place or --overwrite	  */
 #endif /* SWIG_EXT */
@@ -726,9 +727,11 @@ const struct long_option codeset_option_code[] = {
     {"iso2022-jp-2003", codeset_x213a}, /* X-0213(2004)	   */
     {"iso2022-jp-3-compat",   codeset_x0213_s}, /* X-0213 strict  */
     {"iso2022-jp-3-plane1",   codeset_x0213_s}, /* X-0213 strict  */
-    {"iso2022-jp-3-2004", codeset_x213a}, /* X-0213(2004) relax	   */
+    {"iso2022-jp-3-2012", codeset_x213a}, /* X-0213(2004/2012) relax	   */
+    {"iso2022-jp-3-2004", codeset_x213a}, /* X-0213(2004/2012) relax	   */
     {"iso2022-jp-3-2003", codeset_x213a}, /* X-0213(2004) relax	   */
     {"iso2022-jp-3-2000",  codeset_x0213},/* simple X-0213 (2000)  */
+    {"iso2022-jp-3",  codeset_x213a},/* simple X-0213 (2004/2012)  */
     {"euc7-kr",		codeset_kr},
     {"iso-ir-100",	codeset_8859_1},
     {"iso-ir-101",	codeset_8859_2},
@@ -793,9 +796,12 @@ const struct long_option codeset_option_code[] = {
     {"euc-cns",		codeset_euctw},	/* CNS 11643 */
     {"euc-x0213-2003",	codeset_euc_213a},
     {"euc-x0213-2004",	codeset_euc_213a},
+    {"euc-x0213-2012",	codeset_euc_213a},
     {"euc-jis-2003",	codeset_euc_213a},
     {"euc-jis-2004",	codeset_euc_213a},
+    {"euc-jis-2012",	codeset_euc_213a},
     {"euc-jis-2000",	codeset_euc_213},
+    {"euc-jis-3",	codeset_euc_213a},
     {"euc-jisx0213",	codeset_euc_213},
     {"euc",		codeset_eucjp},
     {"x-chinese-eten",	codeset_big5},
@@ -804,11 +810,13 @@ const struct long_option codeset_option_code[] = {
     {"big5p",		codeset_big5p},
     {"hz",		codeset_cnhz},
     {"zw",		codeset_cnzw},
+    {"shift-jis-2012",	codeset_sj_213a},
     {"shift-jis-2004",	codeset_sj_213a},
     {"shift-jis-2003",	codeset_sj_213a},
     {"shift-jis-2000",	codeset_sj_0213},
     {"sjis-x0213-2003",	codeset_sj_213a},
     {"shift-jisx0213",	codeset_sj_0213},
+    {"shift-jis-3",	codeset_sj_213a},
     {"sjis-cellular",	codeset_sjiscl},
     {"sjis",		codeset_sjis},
     {"keis",		codeset_keis},
@@ -1004,7 +1012,6 @@ int main(argc, argv)
 {
     skfFILE  *fin;
     int  c;
-    int sy;
     int	arcc;
     int	skfres = 0;
 #ifdef HAVE_GETENV
@@ -1015,6 +1022,9 @@ int main(argc, argv)
 #endif
     mode_t	oldmode = 0;
     int		ofd;
+#ifdef SKFDEBUG
+    int sy;
+#endif
 
     res_out_code;
     uni_table_init();
@@ -1024,7 +1034,9 @@ int main(argc, argv)
     in_file_name = (char *) calloc(IN_FILE_NAME,sizeof(char));
     inb_file_name = (char *) calloc(IN_FILE_NAME,sizeof(char));
     outs_file_name = (char *) calloc(SUFFIX_LIMIT,sizeof(char));
-    if ((in_file_name == NULL) || (inb_file_name == NULL)) {
+
+    if ((in_file_name == NULL) || (inb_file_name == NULL)
+    	|| (outs_file_name == NULL)) {
 	skferr(SKF_MALLOCERR,(long)0,(long)0); 
 	skf_exit(EXIT_FAILURE);
     };
@@ -1051,18 +1063,18 @@ int main(argc, argv)
 #ifdef NO_GETEUID
 #ifdef HAVE_GETUID
     if (getuid() != 0) {
-	if ((c_arg = getenv("SKFENV"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
-	if ((c_arg = getenv("skfenv"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
+	if ((c_arg = getenv("SKFENV"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
+	if ((c_arg = getenv("skfenv"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
     };
 #else
-    if ((c_arg = getenv("SKFENV"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
-    if ((c_arg = getenv("skfenv"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
+    if ((c_arg = getenv("SKFENV"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
+    if ((c_arg = getenv("skfenv"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
 #endif
 #else
     /* do not read environment value if running as root		   */
     if (geteuid() != 0) {
-	if ((c_arg = getenv("SKFENV"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
-	if ((c_arg = getenv("skfenv"))!= NULL) argeval(2,&c_arg,OPTSTR_LIMIT);
+	if ((c_arg = getenv("SKFENV"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
+	if ((c_arg = getenv("skfenv"))!= NULL) (void)argeval(2,&c_arg,OPTSTR_LIMIT);
     };
 #endif
 #endif
@@ -1071,8 +1083,9 @@ int main(argc, argv)
     c = argc - arcc;
 
 /* --- determine output codeset ---------------------------------- */
-    if (out_code == codeset_binary) out_code = -1;
-    if (out_code == codeset_locale) {
+    if (out_code == codeset_binary) {
+    	out_code = -1;
+    } else if (out_code == codeset_locale) {
     	out_undefined(0,SKF_NOOUT);
 	out_code = -1;
     } else;
@@ -1126,7 +1139,10 @@ int main(argc, argv)
     else;
 
 /* --- output initialize ----------------------------------------- */
-    oconv_init();	/* various initialize			   */
+    if (oconv_init() < 0) {	/* various initialize		   */
+	skferr(SKF_MALLOCERR,(long)0,(long)0);
+	skf_exit(EXIT_FAILURE);
+    } else;
 
     init_all_stats();
 
@@ -1202,9 +1218,11 @@ int main(argc, argv)
 			skferr(SKF_MALLOCERR,(long)0,(long)0);
 			skf_exit(EXIT_FAILURE);
 		    } else;
-		    outs_file_name=".ff";
-		    snprintf(outb_file_name,OUT_FILE_NAME,
-		    	"%s%s",inb_file_name,outs_file_name);
+		    if (snprintf(outb_file_name,OUT_FILE_NAME,
+		    	"%s%s",inb_file_name,outs_file_name) < 0) {
+			skferr(SKF_INTERNALERR,(long)0,(long)0);
+			skf_exit(EXIT_FAILURE);
+		    } else;
 		    oldmode = umask(SKF_MASK_VAL);
 		    if ((ofd = skf_mkstemp(out_file_name)) < 0) {
 			skf_openerr(out_file_name,1);
@@ -1217,11 +1235,13 @@ int main(argc, argv)
 		    } else;
 		    skf_ioinit(fout);
 		} else;
-		sy = skf_in_converter(fin);
 #ifdef	SKFDEBUG
+		sy = skf_in_converter(fin);
 		if (is_v_debug) fprintf(stderr,"\n[EOF:%d]\n",sy);
+#else
+		skf_in_converter(fin);
 #endif
-		skf_fclose (fin);	/* closing file		   */
+		(void)skf_fclose (fin);	/* closing file		   */
 /*@-usedef@*/
 		if (is_nkf_overwrite || is_nkf_in_place) {
 		    struct stat istat;	/*@out@*/
@@ -1259,9 +1279,11 @@ int main(argc, argv)
 			fprintf(stderr," ... %s(%d)\n",outb_file_name,errno);
 			skf_exit(EXIT_FAILURE);
 		    } else;
-		    free(outb_file_name);
 		    (void)umask(oldmode);
 		} else;
+		if (outb_file_name != NULL) {
+		    free(outb_file_name);
+		} else;
 /*@+usedef@*/
 	    };
 	    c++;
@@ -1280,9 +1302,11 @@ int main(argc, argv)
 	fin = stdin;	/*  ... then read input from stdin.	   */
     	setvbuffer(stdin, stdibuf, I_BUFSIZ);	/* buffer control  */
 #endif
-	sy = skf_in_converter(fin);
 #ifdef	SKFDEBUG
-	if (is_v_debug) fprintf(stderr,"\n[EOF]\n");
+	sy = skf_in_converter(fin);
+	if (is_v_debug) fprintf(stderr,"\n[EOF(%d)]\n",sy);
+#else
+	skf_in_converter(fin);
 #endif
     };
 
@@ -1290,10 +1314,14 @@ int main(argc, argv)
     	skf_gangfinish((skfoFILE *)stdout);
     } else;
 
+#ifndef SWIG_EXT
     if (skf_fileout && (is_nkf_overwrite || is_nkf_in_place)) {
     	if (out_file_name != NULL) free(out_file_name);
-    } else;
+    } else {
+	if (out_file_name != NULL) free(out_file_name); /* ??? */
+    };
     if (outs_file_name != NULL) free(outs_file_name);
+#endif
 
     return (skfres);
 }
@@ -1924,7 +1952,7 @@ int argeval(pargc,pargv,limit)
 		      in_codeset = -1; 
 		      out_code = DEFAULT_O; in_param = 0;
 		      nkf_compat = 0; o_encode = 0;
-		      le_detect = 0; k_in = 0; k_out = 0;
+		      le_detect = 0; k_in = (char)0; k_out = (char)0;
 		      pref_subst_char = -1;
 		      mime_fold_llimit = MIME_ENCODE_LLIMIT;
 		      error_opt = 0;
@@ -2066,7 +2094,8 @@ int argeval(pargc,pargv,limit)
 			cq = strchr(cp,'=');
 			if (cq != NULL) {
 			    cq++;
-			    strncpy(outs_file_name,cq,(SUFFIX_LIMIT-1));
+			    strncpy(outs_file_name,cq,(SUFFIX_LIMIT-2));
+			    outs_file_name[SUFFIX_LIMIT-1]='\0';
 			} else;
 			break;
 #endif 
@@ -2282,7 +2311,7 @@ const struct long_option	*opt_t;
 #ifdef SKFDEBUG
     if (is_vv_debug) {
     	if (rval >= 0) 
-	    fprintf(stderr,"opt_parse: %d(%x)\n",rval,rval);
+	    fprintf(stderr,"opt_parse: %d(%x)\n",rval,(unsigned int)rval);
 	else 
 	    fprintf(stderr,"opt_parse: %d\n",rval);
     } else;
@@ -2307,6 +2336,18 @@ skfoFILE *fout;
 /* if any characters hang in encoder, push out these stuffs. 	   */
 /* and also put eol if base64 encode.				   */
     oconv(sFLSH);  /* remains should be cleared	   */
+
+#if defined(FOLD_SUPPORT) && defined(NKF_COMPATMODE)
+/* folding at the end of file					   */
+    if (is_nkf_compat && (fold_count != 0) && fold_fclap && !notrunc_le) {
+#ifdef SKFDEBUG
+	if (is_vv_debug) { fprintf(stderr,"#LEADD#");
+	} else;
+#endif
+    	SKFCRLF();
+    } else;
+#endif
+
     SKFfflush((skfoFILE *)fout);
     if (o_encode) encoder_tail();
     SKFfflush((skfoFILE *)fout);
