@@ -25,7 +25,7 @@
     skf.h:		common definitions
 	v1.30		first written for skf v1.30
 	v1.90 		written for skf v1.9
-    $Id: skf.h,v 1.175 2012/03/17 08:22:12 seiji Exp seiji $
+    $Id: skf.h,v 1.176 2013/07/22 13:42:44 seiji Exp seiji $
 */
 
 #ifndef		INCLUDE_SKFDEFS
@@ -1843,7 +1843,7 @@ unsigned long skf_get_valid_langcode P_((unsigned long,unsigned long));
 #define codeset_cp1252	 108 /* cp1252 (Windows Latin-1)	  */
 #define codeset_utf8n	 109 /* UTF-8N (UTF-8 with BOM)		  */
 #define codeset_utf16lenb 110 /* UTF-16LE (UTF-16LE without BOM)  */
-#define codeset_utf16benb 111 /* UTF-16LE (UTF-16LE without BOM)  */
+#define codeset_utf16benb 111 /* UTF-16BE (UTF-16BE without BOM)  */
 #define codeset_iso2022jp1 112 /* iso-2022-jp-1			  */
 #define codeset_utf32le	113 /* UTF-32LE-BOM (dummy entry)	  */
 #define codeset_utf32be	114 /* UTF-32BE-BOM (dummy entry)	  */
@@ -2078,7 +2078,7 @@ extern void	skferr P_((int, long, long));
 extern void	skf_openerr P_((char *,int));
 extern void	skf_readerr P_((int));
 extern void	error_code_option P_((int));
-extern void	error_extend_option P_((int, char *));
+extern void	error_extend_option P_((int, /*@null@*/ char *));
 
 extern void	show_endian_out();
 extern void	initialize_error();
