@@ -23,7 +23,7 @@
 **********************************************************************
 	skf_fileio.c:	various file io routines
 		v1.x	for skf v1.x
-	$Id: skf_fileio.c,v 1.46 2013/04/07 03:34:21 seiji Exp seiji $
+	$Id: skf_fileio.c,v 1.47 2013/07/22 13:42:44 seiji Exp seiji $
 */
 
 #ifndef _POSIX_SOURCE
@@ -184,7 +184,7 @@ int	*p;		/* file descripter			  */
 	    if (errno != EAGAIN) {
 		return(sABRT);
 	    } else {
-		skf_sleep(1);	/* do not exhaust CPU time	  */
+		(void)skf_sleep(1); /* do not exhaust CPU time	  */
 	    };
 	};
 	skf_fpntr = 0;
@@ -201,7 +201,7 @@ skfoFILE *fout;	/* stdout */
 	skf_exit(EXIT_FAILURE);
     };
 #ifndef USE_FWRITE
-    setvbuffer((FILE *)fout, (char *)stdobuf, O_BUFSIZ);
+    setbuffer((FILE *)fout, (char *)stdobuf, O_BUFSIZ);
 #endif
 
 /* --- preconversion output prepare ------------------------------ */
@@ -223,7 +223,7 @@ skfoFILE	*f;
 	skf_exit(EXIT_FAILURE);
     };
 #else
-    fflush((FILE *)f);
+    (void)fflush((FILE *)f);
 #endif
     obuf_p = 0;
 }
@@ -267,7 +267,7 @@ skfFILE *f;
 void skf_ioinit(fout)
 skfoFILE *fout;	/* stdout */
 {
-    setvbuffer(fout, stdobuf, O_BUFSIZ);
+    setbuffer((FILE *)fout, (char *)stdobuf, O_BUFSIZ);
 /* --- preconversion output prepare ------------------------------ */
     if (o_add_bom) show_endian_out();
     if (add_annon) print_announce(out_codeset);
@@ -357,5 +357,17 @@ char	*nam;
 #endif
 }
 
-
+/* --------------------------------------------------------------- */
+#ifdef HAVE_SETVBUF
+void skf_setvbuf(fp,buf,size)
+FILE *fp;
+char *buf;
+size_t size;
+{
+    if (setvbuf(fp, buf, (int)((buf != NULL) ? _IOFBF : _IONBF), size) != 0) {
+    	skferr(SKF_OBUFERR,(long)3,(long)0);
+	skf_exit(EXIT_FAILURE); /* this should not occur	   */
+    } else;
+}
+#endif
 /* --------------------------------------------------------------- */
