@@ -22,7 +22,7 @@
 **	arising by using whole or a part of this software.
 **********************************************************************
 	skf_fileio.h:	file io routine header
-	$Id: skf_fileio.h,v 1.54 2013/04/07 03:34:21 seiji Exp seiji $
+	$Id: skf_fileio.h,v 1.56 2013/12/19 15:10:25 seiji Exp seiji $
 */
 
 /* -------------------------------------------------------------- */
@@ -61,6 +61,7 @@ extern int decode_hook();
 #define sABRT	(-16)
 #define sRETY	(-17)	/* used as return val in in_converter	  */
 #define sCONT	(-18)
+#define sSUSP	(-19)
 
 #if defined(SWIG_EXT)
 /* -------------------------------------------------------------- */
@@ -87,25 +88,25 @@ extern  int	skf_olimit;
 
 extern  void	*skf_fopen P_((char *, char *));
 #define rGETC(p)	\
-	((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : sEOF)
+	((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : sEOF)
 
 #define	rvGETC(p)	\
 	((encode_cap) ? decode_hook(p,1) : \
-	(((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : sEOF)))
+	(((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : sEOF)))
 
 #define	GETC(p)	\
-	((Qempty) ? (((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	((Qempty) ? (((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 sEOF)) : deque())
  
 #define	vGETC(p)	\
 	((Qempty) ? \
 	 ((encode_cap) ? decode_hook(p,0) : \
-	  ((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	  ((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 sEOF)) : deque())
 #define	vcGETC(p,x)	\
 	((Qempty) ? \
 	 ((encode_cap) ? decode_hook(p,0) : \
-	  ((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	  ((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 sEOF)) : deque())
 
 #define unGETC(c,f) ((skf_fpntr > 0) ? (skf_fpntr--) : -1)
@@ -143,28 +144,28 @@ extern skfFILE	*skf_fopen P_((char *,char *));
 extern  size_t	skf_strlen P_((char *,int));
 
 #define	rGETC(p)	\
-	((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 skf_fillbuf(p))	
 
 #define	rvGETC(p)	\
 	((encode_cap) ? decode_hook(p,1) : \
-	(((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	(((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 skf_fillbuf(p))))
 
 #define	GETC(p)	\
-	((Qempty) ? (((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	((Qempty) ? (((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 skf_fillbuf(p))) : deque())
  
 #define	vGETC(p)	\
 	((Qempty) ? \
 	 ((encode_cap) ? decode_hook(p,0) : \
-	  ((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	  ((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 skf_fillbuf(p))) : deque())
  
 #define	vcGETC(p,x)	\
 	((Qempty) ? \
 	 ((encode_cap) ? decode_hook(p,0) : \
-	  ((skf_fpntr < buf_p) ? (stdibuf[skf_fpntr++]) : \
+	  ((skf_fpntr < buf_p) ? (int)(stdibuf[skf_fpntr++]) : \
 				 skf_fillbuf(p))) : deque())
  
 #define	unGETC(c,f) ((*f < 0) ? -1 : \
@@ -240,8 +241,7 @@ extern skfoFILE *fout;
 #ifdef USE_FWRITE
 #define setvbuffer(fp, buf,size)
 #else
-#define	setvbuffer(fp, buf, size) \
-    setvbuf(fp, buf, (int)((buf != NULL) ? _IOFBF : _IONBF), (size_t) size)
+#define	setvbuffer(fp, buf, size) skf_setvbuf(fp, buf, (size_t) size)
 #endif
 
 #if defined(__MINGW32__)
