@@ -23,7 +23,7 @@
 **********************************************************************
     ucodoconv.c: output converters for Unicode(TM) variants
 	v1.90	Newly written from unic*de.c parsing
-    $Id: ucodoconv.c,v 1.76 2011/09/20 14:21:19 seiji Exp seiji $
+    $Id: ucodoconv.c,v 1.77 2013/07/22 13:42:44 seiji Exp seiji $
 **/
 
 #include <stdio.h>
@@ -607,18 +607,18 @@ char *utf8_urioutstr(x)
 skf_ucode x;
 {
     if (x < 0x80) {
-    	snprintf(ucod_cbuf,1,"%c",x);
+    	(void)snprintf(ucod_cbuf,1,"%c",x);
     } else if (x < 0x800) {
-	snprintf(ucod_cbuf,6,"\%02x\%02x",
+	(void)snprintf(ucod_cbuf,6,"\%02x\%02x",
 		(ZF23VAL + ((x & ZL23MSK) >> 6)),
 		((x & Z1MSK) | ZCVAL));
     } else if (x < 0x10000) {
-	snprintf(ucod_cbuf,9,"\%02x\%02x\%02x",
+	(void)snprintf(ucod_cbuf,9,"\%02x\%02x\%02x",
 		(ZF3VAL + ((x & ZL3MSK) >> 12)),
 		(ZF2VAL + ((x & ZL2MSK) >> 6)),
 		((x & Z1MSK) | ZCVAL));
     } else if ((x <= 0x10ffff) && (x >= 0x10000) && !limit_ucs2) {
-	snprintf(ucod_cbuf,12,"\%02lx\%02lx\%02x\%02x",
+	(void)snprintf(ucod_cbuf,12,"\%02lx\%02lx\%02x\%02x",
 		(ZF4VAL + ((x & ZL4MSK) >> 18)),
 		(ZF2VAL + ((x & ZL43MSK) >> 12)),
 		(ZF2VAL + ((x & ZL2MSK) >> 6)),
@@ -758,14 +758,14 @@ skf_ucode cc;		/* table lookup result */
 	    		|| ((cc >= 0xe000) && (cc < 0xf900))) {
 	    	/* BSP and not surrogate nor compat plane	   */
 		encode_pslenset(&plen,&slen,cc);
-		mime_clip_test(plen,slen);
+		(void)mime_clip_test(plen,slen);
 	    } else if (cc >= 0x10000) {
 		encode_pslenset(&plen,&slen,cc);
-		mime_clip_test(plen,slen);
+		(void)mime_clip_test(plen,slen);
 	    } else if (cc < 0xe000) { /* surrogate - special area  */
 		/* X0213 ligature count is processed within parser,*/
 		/* we just care about current cursor position.	   */
-		mime_clip_test(0,0);
+		(void)mime_clip_test(0,0);
 	    } else {	/* 0xf900 - 0xffff			   */
 	    	c1 = (skf_ucode)(cc & 0xffL);
 	    	c3 = (skf_ucode)((cc >> 8) & 0xffL);
@@ -810,7 +810,7 @@ skf_ucode cc;		/* table lookup result */
 		    encode_pslenset(&plen,&slen,ucode_undef);
 		};
 	    };
-	    mime_clip_test(plen,slen);
+	    (void)mime_clip_test(plen,slen);
 	} else {	/* ASCII and suppressed case		   */
 			/* Note: cr/lf comes here.		   */
 	    if (is_lineend(ch) && is_ucs_utf16(conv_cap)) {
@@ -820,10 +820,10 @@ skf_ucode cc;		/* table lookup result */
 	    	if (ch < A_SP) encode_pslenset(&plen,&slen,ch);
 		else;		/* undefined. not processed here   */
 	    } else;
-	    mime_clip_test(plen,slen);
+	    (void)mime_clip_test(plen,slen);
 	};
     } else {	/* if c1 < 0, output as it is.			   */
-	mime_clip_test(0,0);
+	(void)mime_clip_test(0,0);
     };
     return;
 }
